pub trait ModuleBuilder<M: Module> {
// Required method
fn build(self) -> Result<M::Capability, M::Error>;
}Expand description
The standard builder trait for module initialization.
All modules must have a builder that implements this trait.
The build method is the only required method and returns
the module’s capability or an error.
Required Methods
Sourcefn build(self) -> Result<M::Capability, M::Error>
fn build(self) -> Result<M::Capability, M::Error>
Build the module’s capability.
Returns Ok(M::Capability) on success, or Err(M::Error) on failure.