Module marker

Module marker 

Marker types for modules without configuration or dependencies.

Structs

NoConfig
Marker type for modules that do not require configuration. Modules using NoConfig do not need to call .config() on their builder.
NoRequirements
Marker type for modules that do not require dependencies. Modules using NoRequirements do not need to call .requirements() on their builder.